@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import warnings
+
 from tencentcloud.common.abstract_model import AbstractModel
 
 
@@ -23,29 +25,63 @@ class InitOralProcessRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param SessionId: 语音段唯一标识，一段语音一个SessionId
+        :param SessionId: 语音段唯一标识，一段完整语音使用一个SessionId，不同语音段的评测需要使用不同的SessionId。一般使用uuid(通用唯一识别码)来作为它的值，要尽量保证SessionId的唯一性。
         :type SessionId: str
-        :param RefText: 被评估语音对应的文本，句子模式下不超过个 20 单词或者中文文字，段落模式不超过 120 单词或者中文文字，中文评估使用 utf-8 编码，自由说模式该值传空。如需要在单词模式和句子模式下使用自定义音素，可以通过设置 TextMode 使用[音素标注](https://cloud.tencent.com/document/product/884/33698)。
+        :param RefText: 被评估语音对应的文本，仅支持中文和英文。
+句子模式下不超过个 30 单词或者中文文字，段落模式不超过 120 单词或者中文文字，中文评估使用 utf-8 编码，自由说模式该值无效。
+关于RefText的文本键入要求，请参考[评测模式介绍](https://cloud.tencent.com/document/product/884/56131)。
+如需要在评测模式下使用自定义注音（支持中英文），可以通过设置「TextMode」参数实现，设置方式请参考[音素标注](https://cloud.tencent.com/document/product/884/33698)。
         :type RefText: str
-        :param WorkMode: 语音输入模式，0：流式分片，1：非流式一次性评估
+        :param WorkMode: 语音输入模式
+0：流式分片
+1：非流式一次性评估
+推荐使用流式分片传输。
         :type WorkMode: int
-        :param EvalMode: 评估模式，0：词模式（中文评测模式下为文字模式），1：句子模式，2：段落模式，3：自由说模式，当为词模式评估时，能够提供每个音节的评估信息，当为句子模式时，能够提供完整度和流利度信息。4: 英文单词音素诊断评测模式，针对一个单词音素诊断评测。
+        :param EvalMode: 评测模式
+0：单词/单字模式（中文评测模式下为单字模式）
+1：句子模式
+2：段落模式
+3：自由说模式
+4：单词音素纠错模式
+5：情景评测模式
+6：句子多分支评测模式
+7：单词实时评测模式
+8：拼音评测模式
+关于每种评测模式的详细介绍，以及适用场景，请参考[评测模式介绍](https://cloud.tencent.com/document/product/884/56131)。
         :type EvalMode: int
-        :param ScoreCoeff: 评价苛刻指数，取值为[1.0 - 4.0]范围内的浮点数，用于平滑不同年龄段的分数，1.0为小年龄段，4.0为最高年龄段
+        :param ScoreCoeff: 评价苛刻指数。取值为[1.0 - 4.0]范围内的浮点数，用于平滑不同年龄段的分数。
+1.0：适用于最小年龄段用户，一般对应儿童应用场景；
+4.0：适用于最高年龄段用户，一般对应成人严格打分场景。
         :type ScoreCoeff: float
-        :param SoeAppId: 业务应用ID，与账号应用APPID无关，是用来方便客户管理服务的参数，新的 SoeAppId 可以在[控制台](https://console.cloud.tencent.com/soe)【应用管理】下新建。
+        :param SoeAppId: 业务应用ID，与账号应用APPID无关，是用来方便客户管理服务的参数，新的 SoeAppId 可以在[控制台](https://console.cloud.tencent.com/soe)【应用管理】下新建。如果没有新建SoeAppId，请勿填入该参数，否则会报欠费错误。
         :type SoeAppId: str
         :param IsLongLifeSession: 长效session标识，当该参数为1时，session的持续时间为300s，但会一定程度上影响第一个数据包的返回速度，且TransmitOralProcess必须同时为1才可生效。
         :type IsLongLifeSession: int
-        :param StorageMode: 音频存储模式，0：不存储，1：存储到公共对象存储，输出结果为该会话最后一个分片TransmitOralProcess 返回结果 AudioUrl 字段，2：永久存储音频，需要提工单申请，会产生一定存储费用，3：自定义存储，将音频存储到自定义的腾讯云[对象存储](https://cloud.tencent.com/product/cos)中，需要提工单登记存储信息。
+        :param StorageMode: 音频存储模式
+0：不存储
+1：存储到公共对象存储，不会产生费用，存储时间为一个月。输出结果为该会话最后一个分片TransmitOralProcess 返回结果 AudioUrl 字段；
+2：永久存储音频，需要提工单申请，会产生一定的存储费用；
+3：自定义存储，将音频存储到自定义的腾讯云[对象存储](https://cloud.tencent.com/product/cos)中。
+注：对可用性要求较高的用户建议自行存储至腾讯云COS。
         :type StorageMode: int
-        :param SentenceInfoEnabled: 输出断句中间结果标识，0：不输出，1：输出，通过设置该参数，可以在评估过程中的分片传输请求中，返回已经评估断句的中间结果，中间结果可用于客户端 UI 更新，输出结果为TransmitOralProcess请求返回结果 SentenceInfoSet 字段。
+        :param SentenceInfoEnabled: 输出断句中间结果标识
+0：不输出
+1：输出，通过设置该参数
+可以在评估过程中的分片传输请求中，返回已经评估断句的中间结果，中间结果可用于客户端 UI 更新，输出结果为TransmitOralProcess请求返回结果 SentenceInfoSet 字段。
         :type SentenceInfoEnabled: int
-        :param ServerType: 评估语言，0：英文，1：中文。
+        :param ServerType: 评估语言
+0：英文
+1：中文
         :type ServerType: int
-        :param IsAsync: 异步模式标识，0：同步模式，1：异步模式，可选值参考[服务模式](https://cloud.tencent.com/document/product/884/33697)。
+        :param IsAsync: 异步模式标识
+0：同步模式
+1：异步模式（一般情况不建议使用异步模式）
+可选值参考[服务模式](https://cloud.tencent.com/document/product/884/33697)。
         :type IsAsync: int
-        :param TextMode: 输入文本模式，0: 普通文本，1：[音素结构](https://cloud.tencent.com/document/product/884/33698)文本。2：音素注册模式（提工单注册需要使用音素的单词）。
+        :param TextMode: 输入文本模式
+0: 普通文本
+1：[音素结构](https://cloud.tencent.com/document/product/884/33698)文本
+2：音素注册模式（提工单注册需要使用音素的单词）。
         :type TextMode: int
         """
         self.SessionId = None
@@ -75,6 +111,13 @@ class InitOralProcessRequest(AbstractModel):
         self.ServerType = params.get("ServerType")
         self.IsAsync = params.get("IsAsync")
         self.TextMode = params.get("TextMode")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class InitOralProcessResponse(AbstractModel):
@@ -129,6 +172,13 @@ class Keyword(AbstractModel):
         self.ScoreCoeff = params.get("ScoreCoeff")
         self.ServerType = params.get("ServerType")
         self.TextMode = params.get("TextMode")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class KeywordEvaluateRequest(AbstractModel):
@@ -139,20 +189,27 @@ class KeywordEvaluateRequest(AbstractModel):
     def __init__(self):
         """
         :param SeqId: 流式数据包的序号，从1开始，当IsEnd字段为1后后续序号无意义，当IsLongLifeSession不为1且为非流式模式时无意义。
+注意：序号上限为3000，不能超过上限。
         :type SeqId: int
         :param IsEnd: 是否传输完毕标志，若为0表示未完毕，若为1则传输完毕开始评估，非流式模式下无意义。
         :type IsEnd: int
-        :param VoiceFileType: 语音文件类型 	1: raw, 2: wav, 3: mp3, 4: speex (语言文件格式目前仅支持 16k 采样率 16bit 编码单声道，如有不一致可能导致评估不准确或失败)。
+        :param VoiceFileType: 语音文件类型
+1: raw
+2: wav
+3: mp3
+4: speex
+语音文件格式目前仅支持 16k 采样率 16bit 编码单声道，如有不一致可能导致评估不准确或失败。
         :type VoiceFileType: int
-        :param VoiceEncodeType: 语音编码类型	1:pcm。
+        :param VoiceEncodeType: 语音编码类型
+1:pcm
         :type VoiceEncodeType: int
-        :param UserVoiceData: 当前数据包数据, 流式模式下数据包大小可以按需设置，在网络良好的情况下，建议设置为0.5k，且必须保证分片帧完整（16bit的数据必须保证音频长度为偶数），编码格式要求为BASE64。
+        :param UserVoiceData: 当前数据包数据, 流式模式下数据包大小可以按需设置，在网络良好的情况下，建议设置为1k，且必须保证分片帧完整（16bit的数据必须保证音频长度为偶数），编码格式要求为BASE64。
         :type UserVoiceData: str
-        :param SessionId: 语音段唯一标识，一个完整语音一个SessionId。
+        :param SessionId: 语音段唯一标识，一段完整语音使用一个SessionId，不同语音段的评测需要使用不同的SessionId。一般使用uuid(通用唯一识别码)来作为它的值，要尽量保证SessionId的唯一性。
         :type SessionId: str
         :param Keywords: 关键词列表
         :type Keywords: list of Keyword
-        :param SoeAppId: 业务应用ID，与账号应用APPID无关，是用来方便客户管理服务的参数，新的 SoeAppId 可以在[控制台](https://console.cloud.tencent.com/soe)【应用管理】下新建。
+        :param SoeAppId: 业务应用ID，与账号应用APPID无关，是用来方便客户管理服务的参数，新的 SoeAppId 可以在[控制台](https://console.cloud.tencent.com/soe)【应用管理】下新建。如果没有新建SoeAppId，请勿填入该参数，否则会报欠费错误。
         :type SoeAppId: str
         :param IsQuery: 查询标识，当该参数为1时，该请求为查询请求，请求返回该 Session 评估结果。
         :type IsQuery: int
@@ -183,6 +240,13 @@ class KeywordEvaluateRequest(AbstractModel):
                 self.Keywords.append(obj)
         self.SoeAppId = params.get("SoeAppId")
         self.IsQuery = params.get("IsQuery")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class KeywordEvaluateResponse(AbstractModel):
@@ -194,7 +258,7 @@ class KeywordEvaluateResponse(AbstractModel):
         """
         :param KeywordScores: 关键词得分
         :type KeywordScores: list of KeywordScore
-        :param SessionId: 语音段唯一标识，一段语音一个SessionId
+        :param SessionId: 语音段唯一标识，一段完整语音使用一个SessionId，不同语音段的评测需要使用不同的SessionId。一般使用uuid(通用唯一识别码)来作为它的值，要尽量保证SessionId的唯一性。
         :type SessionId: str
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
@@ -256,6 +320,13 @@ class KeywordScore(AbstractModel):
                 obj._deserialize(item)
                 self.Words.append(obj)
         self.SuggestedScore = params.get("SuggestedScore")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class PhoneInfo(AbstractModel):
@@ -273,7 +344,7 @@ class PhoneInfo(AbstractModel):
         :type PronAccuracy: float
         :param DetectedStress: 当前音节是否检测为重音
         :type DetectedStress: bool
-        :param Phone: 当前音节
+        :param Phone: 当前音节，当前评测识别的音素
         :type Phone: str
         :param Stress: 当前音节是否应为重音
         :type Stress: bool
@@ -281,6 +352,8 @@ class PhoneInfo(AbstractModel):
         :type ReferencePhone: str
         :param MatchTag: 当前词与输入语句的匹配情况，0：匹配单词、1：新增单词、2：缺少单词、3：错读的词、4：未录入单词。
         :type MatchTag: int
+        :param ReferenceLetter: 参考字符，在单词诊断模式下，代表音素对应的原始文本
+        :type ReferenceLetter: str
         """
         self.MemBeginTime = None
         self.MemEndTime = None
@@ -290,6 +363,7 @@ class PhoneInfo(AbstractModel):
         self.Stress = None
         self.ReferencePhone = None
         self.MatchTag = None
+        self.ReferenceLetter = None
 
 
     def _deserialize(self, params):
@@ -301,6 +375,14 @@ class PhoneInfo(AbstractModel):
         self.Stress = params.get("Stress")
         self.ReferencePhone = params.get("ReferencePhone")
         self.MatchTag = params.get("MatchTag")
+        self.ReferenceLetter = params.get("ReferenceLetter")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class SentenceInfo(AbstractModel):
@@ -343,6 +425,13 @@ class SentenceInfo(AbstractModel):
         self.PronFluency = params.get("PronFluency")
         self.PronCompletion = params.get("PronCompletion")
         self.SuggestedScore = params.get("SuggestedScore")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class TransmitOralProcessRequest(AbstractModel):
@@ -353,18 +442,25 @@ class TransmitOralProcessRequest(AbstractModel):
     def __init__(self):
         """
         :param SeqId: 流式数据包的序号，从1开始，当IsEnd字段为1后后续序号无意义，当IsLongLifeSession不为1且为非流式模式时无意义。
+注意：序号上限为3000，不能超过上限。
         :type SeqId: int
         :param IsEnd: 是否传输完毕标志，若为0表示未完毕，若为1则传输完毕开始评估，非流式模式下无意义。
         :type IsEnd: int
-        :param VoiceFileType: 语音文件类型 	1:raw, 2:wav, 3:mp3(三种格式目前仅支持16k采样率16bit编码单声道，如有不一致可能导致评估不准确或失败)。
+        :param VoiceFileType: 语音文件类型
+1: raw
+2: wav
+3: mp3
+4: speex
+语音文件格式目前仅支持 16k 采样率 16bit 编码单声道，如有不一致可能导致评估不准确或失败。
         :type VoiceFileType: int
-        :param VoiceEncodeType: 语音编码类型	1:pcm。
+        :param VoiceEncodeType: 语音编码类型
+1:pcm
         :type VoiceEncodeType: int
         :param UserVoiceData: 当前数据包数据, 流式模式下数据包大小可以按需设置，在网络稳定时，分片大小建议设置0.5k，且必须保证分片帧完整（16bit的数据必须保证音频长度为偶数），编码格式要求为BASE64。
         :type UserVoiceData: str
-        :param SessionId: 语音段唯一标识，一个完整语音一个SessionId。
+        :param SessionId: 语音段唯一标识，一段完整语音使用一个SessionId，不同语音段的评测需要使用不同的SessionId。一般使用uuid(通用唯一识别码)来作为它的值，要尽量保证SessionId的唯一性。
         :type SessionId: str
-        :param SoeAppId: 业务应用ID，与账号应用APPID无关，是用来方便客户管理服务的参数，新的 SoeAppId 可以在[控制台](https://console.cloud.tencent.com/soe)【应用管理】下新建。
+        :param SoeAppId: 业务应用ID，与账号应用APPID无关，是用来方便客户管理服务的参数，新的 SoeAppId 可以在[控制台](https://console.cloud.tencent.com/soe)【应用管理】下新建。如果没有新建SoeAppId，请勿填入该参数，否则会报欠费错误。
         :type SoeAppId: str
         :param IsLongLifeSession: 长效session标识，当该参数为1时，session的持续时间为300s，但会一定程度上影响第一个数据包的返回速度。当InitOralProcess接口调用时此项为1时，此项必填1才可生效。
         :type IsLongLifeSession: int
@@ -392,6 +488,13 @@ class TransmitOralProcessRequest(AbstractModel):
         self.SoeAppId = params.get("SoeAppId")
         self.IsLongLifeSession = params.get("IsLongLifeSession")
         self.IsQuery = params.get("IsQuery")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class TransmitOralProcessResponse(AbstractModel):
@@ -465,6 +568,7 @@ class TransmitOralProcessWithInitRequest(AbstractModel):
     def __init__(self):
         """
         :param SeqId: 流式数据包的序号，从1开始，当IsEnd字段为1后后续序号无意义，当IsLongLifeSession不为1且为非流式模式时无意义。
+注意：序号上限为3000，不能超过上限。
         :type SeqId: int
         :param IsEnd: 是否传输完毕标志，若为0表示未完毕，若为1则传输完毕开始评估，非流式模式下无意义。
         :type IsEnd: int
@@ -484,6 +588,7 @@ class TransmitOralProcessWithInitRequest(AbstractModel):
         :type SessionId: str
         :param RefText: 被评估语音对应的文本，仅支持中文和英文。
 句子模式下不超过个 30 单词或者中文文字，段落模式不超过 120 单词或者中文文字，中文评估使用 utf-8 编码，自由说模式该值无效。
+关于RefText的文本键入要求，请参考[评测模式介绍](https://cloud.tencent.com/document/product/884/56131)。
 如需要在评测模式下使用自定义注音（支持中英文），可以通过设置「TextMode」参数实现，设置方式请参考[音素标注](https://cloud.tencent.com/document/product/884/33698)。
         :type RefText: str
         :param WorkMode: 语音输入模式
@@ -501,6 +606,7 @@ class TransmitOralProcessWithInitRequest(AbstractModel):
 6：句子多分支评测模式
 7：单词实时评测模式
 8：拼音评测模式
+关于每种评测模式的详细介绍，以及适用场景，请参考[评测模式介绍](https://cloud.tencent.com/document/product/884/56131)。
         :type EvalMode: int
         :param ScoreCoeff: 评价苛刻指数。取值为[1.0 - 4.0]范围内的浮点数，用于平滑不同年龄段的分数。
 1.0：适用于最小年龄段用户，一般对应儿童应用场景；
@@ -512,7 +618,7 @@ class TransmitOralProcessWithInitRequest(AbstractModel):
 0：不存储
 1：存储到公共对象存储，不会产生费用，存储时间为一个月。输出结果为该会话最后一个分片TransmitOralProcess 返回结果 AudioUrl 字段；
 2：永久存储音频，需要提工单申请，会产生一定的存储费用；
-3：自定义存储，将音频存储到自定义的腾讯云[对象存储](https://cloud.tencent.com/product/cos)中，需要提工单登记存储信息。关于自定义存储cos基础设置的方式，请查看下文自定义存储cos基础设置流程。
+3：自定义存储，将音频存储到自定义的腾讯云[对象存储](https://cloud.tencent.com/product/cos)中。
 注：对可用性要求较高的用户建议自行存储至腾讯云COS。
         :type StorageMode: int
         :param SentenceInfoEnabled: 输出断句中间结果标识
@@ -574,6 +680,13 @@ class TransmitOralProcessWithInitRequest(AbstractModel):
         self.IsAsync = params.get("IsAsync")
         self.IsQuery = params.get("IsQuery")
         self.TextMode = params.get("TextMode")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class TransmitOralProcessWithInitResponse(AbstractModel):
@@ -686,4 +799,11 @@ class WordRsp(AbstractModel):
                 obj = PhoneInfo()
                 obj._deserialize(item)
                 self.PhoneInfos.append(obj)
-        self.ReferenceWord = params.get("ReferenceWord")
\ No newline at end of file
+        self.ReferenceWord = params.get("ReferenceWord")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
\ No newline at end of file
